/* volume.c - Common Volume service routines.
 *
 * Copyright (C) 2005-2007   Ivo Clarysse
 * Copyright (C) 2013 Andrey Demenev
 * Copyright (C) 2014 Buffalo
 *
 * This file is part of GMediaRender.
 *
 * GMediaRender is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * GMediaRender is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with GMediaRender; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 *
 */
 
#include "volume.h"

// We split our volume range into two ranges with different slope.
// The first half goes from min_db ... mid_db, the second half
// from mid_db .. max_db.
static const float vol_min_db = -60.0;
static const float vol_mid_db = -20.0;
static const float vol_max_db = 0.0;

static const int vol_mid_point = VOLUME_MAX_VAL/2;  // volume_range.max / 2

// Note, some players don't read the range and assume 0..100. So better leave
// it like this.
struct param_range volume_range = { 0, VOLUME_MAX_VAL, 1 };
struct param_range volume_db_range = { -60 * 256, 0, 0 };  // volume_min_db

float volume_level_to_decibel(int volume) {
	if (volume < volume_range.min) volume = volume_range.min;
	if (volume > volume_range.max) volume = volume_range.max;
	if (volume < volume_range.max / 2) {
		return vol_min_db
			+ (vol_mid_db - vol_min_db) / vol_mid_point * volume;
	}
	else {
		const int range = volume_range.max - vol_mid_point;
		return vol_mid_db
			+ ((vol_max_db - vol_mid_db) / range
			   * (volume - vol_mid_point));
	}
}

int volume_decibel_to_level(float decibel) {
	if (decibel < vol_min_db) return volume_range.min;
	if (decibel > vol_max_db) return volume_range.max;
	if (decibel < vol_mid_db) {
		return (decibel - vol_min_db) * vol_mid_point / (vol_mid_db - vol_min_db);
	}
	else {
		const int range = volume_range.max - vol_mid_point;
		return (decibel - vol_mid_db) * range / (vol_max_db - vol_mid_db) + vol_mid_point;
	}
}
